@@ -24,7 +24,7 @@
 #include <glib.h>
 #include <glib/gi18n.h>
 #include <gtk/gtk.h>
-#include <packagekit-glib/packagekit.h>
+#include <packagekit-glib2/packagekit.h>
 #include <gconf/gconf-client.h>
 
 #include "egg-debug.h"
@@ -51,20 +51,20 @@ gpk_dialog_package_id_name_join_locale (gchar **package_ids)
 	guint i;
 	guint length;
 	gchar *text;
-	PkPackageId *ident;
 	GPtrArray *array;
 	gchar **array_strv;
+	gchar **split;
 
 	length = g_strv_length (package_ids);
-	array = g_ptr_array_new ();
+	array = g_ptr_array_new_with_free_func (g_free);
 	for (i=0; i<length; i++) {
-		ident = pk_package_id_new_from_string (package_ids[i]);
-		if (ident == NULL) {
+		split = pk_package_id_split (package_ids[i]);
+		if (split == NULL) {
 			egg_warning ("failed to split %s", package_ids[i]);
 			continue;
 		}
-		g_ptr_array_add (array, g_strdup (ident->name));
-		pk_package_id_free (ident);
+		g_ptr_array_add (array, g_strdup (split[0]));
+		g_strfreev (split);
 	}
 	array_strv = pk_ptr_array_to_strv (array);
 	text = gpk_strv_join_locale (array_strv);
@@ -73,41 +73,46 @@ gpk_dialog_package_id_name_join_locale (gchar **package_ids)
 		/* TRANSLATORS: This is when we have over 5 items, and we're not interested in detail */
 		text = g_strdup (_("many packages"));
 	}
-	g_ptr_array_foreach (array, (GFunc) g_free, NULL);
-	g_ptr_array_free (array, TRUE);
+	g_ptr_array_unref (array);
 	return text;
 }
 
 /**
- * gpk_dialog_package_list_to_list_store:
+ * gpk_dialog_package_array_to_list_store:
  **/
 static GtkListStore *
-gpk_dialog_package_list_to_list_store (PkPackageList *list)
+gpk_dialog_package_array_to_list_store (GPtrArray *array)
 {
 	GtkListStore *store;
 	GtkTreeIter iter;
-	const PkPackageObj *obj;
+	PkPackage *item;
 	PkDesktop *desktop;
 	const gchar *icon;
-	gchar *package_id;
 	gchar *text;
-	guint length;
 	guint i;
+	gchar **split;
+	PkInfoEnum info;
+	gchar *package_id = NULL;
+	gchar *summary = NULL;
 
 	desktop = pk_desktop_new ();
 	store = gtk_list_store_new (GPK_DIALOG_STORE_LAST, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING);
-	length = pk_package_list_get_size (list);
 
 	/* add each well */
-	for (i=0; i<length; i++) {
-		obj = pk_package_list_get_obj (list, i);
-		text = gpk_package_id_format_twoline (obj->id, obj->summary);
-		package_id = pk_package_id_to_string (obj->id);
+	for (i=0; i<array->len; i++) {
+		item = g_ptr_array_index (array, i);
+		g_object_get (item,
+			      "info", &info,
+			      "package-id", &package_id,
+			      "summary", &summary,
+			      NULL);
+		text = gpk_package_id_format_twoline (package_id, summary);
 
 		/* get the icon */
-		icon = gpk_desktop_guess_icon_name (desktop, obj->id->name);
+		split = pk_package_id_split (package_id);
+		icon = gpk_desktop_guess_icon_name (desktop, split[0]);
 		if (icon == NULL)
-			icon = gpk_info_enum_to_icon_name (PK_INFO_ENUM_INSTALLED);
+			icon = gpk_info_enum_to_icon_name (info);
 
 		gtk_list_store_append (store, &iter);
 		gtk_list_store_set (store, &iter,
@@ -115,8 +120,10 @@ gpk_dialog_package_list_to_list_store (PkPackageList *list)
 				    GPK_DIALOG_STORE_ID, package_id,
 				    GPK_DIALOG_STORE_TEXT, text,
 				    -1);
-		g_free (text);
+		g_strfreev (split);
 		g_free (package_id);
+		g_free (summary);
+		g_free (text);
 	}
 
 	g_object_unref (desktop);
@@ -170,16 +177,15 @@ gpk_dialog_widget_unrealize_unref_cb (GtkWidget *widget, GObject *obj)
  * gpk_dialog_embed_package_list_widget:
  **/
 gboolean
-gpk_dialog_embed_package_list_widget (GtkDialog *dialog, PkPackageList *list)
+gpk_dialog_embed_package_list_widget (GtkDialog *dialog, GPtrArray *array)
 {
 	GtkWidget *scroll;
 	GtkListStore *store;
 	GtkWidget *widget;
-	guint length;
 	const guint row_height = 48;
 
 	/* convert to a store */
-	store = gpk_dialog_package_list_to_list_store (list);
+	store = gpk_dialog_package_array_to_list_store (array);
 
 	/* create a treeview to hold the store */
 	widget = gtk_tree_view_new_with_model (GTK_TREE_MODEL (store));
@@ -196,11 +202,10 @@ gpk_dialog_embed_package_list_widget (GtkDialog *dialog, PkPackageList *list)
 	gtk_container_set_border_width (GTK_CONTAINER (scroll), 6);
 
 	/* only allow more space if there are a large number of items */
-	length = pk_package_list_get_size (list);
-	if (length > 5) {
+	if (array->len > 5) {
 		gtk_widget_set_size_request (GTK_WIDGET (scroll), -1, (row_height * 5) + 8);
-	} else if (length > 1) {
-		gtk_widget_set_size_request (GTK_WIDGET (scroll), -1, (row_height * length) + 8);
+	} else if (array->len > 1) {
+		gtk_widget_set_size_request (GTK_WIDGET (scroll), -1, (row_height * array->len) + 8);
 	}
 
 	/* add scrolled window */
@@ -316,3 +321,35 @@ gpk_dialog_embed_do_not_show_widget (GtkDialog *dialog, const gchar *key)
 	return TRUE;
 }
 
+/**
+ * gpk_dialog_embed_download_size_widget:
+ **/
+gboolean
+gpk_dialog_embed_download_size_widget (GtkDialog *dialog, const gchar *title, guint64 size)
+{
+	GtkWidget *label;
+	GtkWidget *hbox;
+	GtkWidget *widget;
+	gchar *text;
+	gchar *size_str;
+
+	/* add a checkbutton for deps screen */
+	size_str = g_format_size_for_display (size);
+	text = g_strdup_printf ("%s: %s", title, size_str);
+	hbox = gtk_hbox_new (FALSE, 6);
+	widget = gtk_dialog_get_content_area (GTK_DIALOG(dialog));
+	gtk_container_add_with_properties (GTK_CONTAINER (widget), hbox,
+					   "expand", FALSE,
+					   "fill", FALSE,
+					   NULL);
+
+	/* add a label */
+	label = gtk_label_new (text);
+	gtk_box_pack_start (GTK_BOX(hbox), label, FALSE, FALSE, 0);
+	gtk_widget_show (label);
+	gtk_widget_show (hbox);
+	g_free (text);
+	g_free (size_str);
+	return TRUE;
+}
+
